/// <reference types="node" />
/**
 * Template string type for AUIDs
 */
export type AUID = `${string}-${string}-${string}-${string}`;
/**
 * Generates a crytografically strong AUID
 *
 * With `(2 ^ 4) ^ (16*4)` or `2 ^ 256` or `1.1579209e+77` possible combinations
 */
export declare function generateAUID(): AUID;
/**
 * Generate a random raw Buffer data that represents an AUID
 */
export declare function generateAUID_raw(): Buffer;
/**
 * Generate an AUID from the raw Buffer data
 */
export declare function generateAUID_fromRaw(data: Buffer): AUID;
/**
 * Generate a raw Buffer data from an AUID
 */
export declare function generateAUID_toRaw(data: AUID): Buffer;
/**
 * Generates a crytografically strong AUID **inside of the browser environment**
 *
 * With `(2 ^ 4) ^ (16*4)` or `2 ^ 256` or `1.1579209e+77` possible combinations
 */
export declare function generateAUID_dom(): AUID;
export declare function generateAUID_dom_raw(): Uint8Array;
export declare function generateAUID_dom_fromRaw(data: Uint8Array): AUID;
/**
 * Generate a raw Uint8Array from an AUID
 */
export declare function generateAUID_dom_toRaw(data: AUID): Uint8Array;
/**
 * Fullproof regex for AUIDs
 */
export declare const isAUID: RegExp;
